Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2654)

Unified Diff: chrome/browser/infobars/infobar_delegate.h

Issue 15067008: [InfoBar] Add InfoBarDelegate::GetIconID() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Nit fixes redux Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/infobars/infobar_delegate.h
diff --git a/chrome/browser/infobars/infobar_delegate.h b/chrome/browser/infobars/infobar_delegate.h
index 1fb7d632a9d9b1197125bcdeefbc3e1bd00099e3..2f3ca28017ba990d36df4c05d8ab18fc692e9f63 100644
--- a/chrome/browser/infobars/infobar_delegate.h
+++ b/chrome/browser/infobars/infobar_delegate.h
@@ -47,6 +47,9 @@ class InfoBarDelegate {
UNKNOWN_INFOBAR,
};
+ // Value to use when the InfoBar has no icon to show.
+ static const int kNoIconID;
+
virtual ~InfoBarDelegate();
virtual InfoBarAutomationType GetInfoBarAutomationType() const;
@@ -78,9 +81,9 @@ class InfoBarDelegate {
// Called when the user clicks on the close button to dismiss the infobar.
virtual void InfoBarDismissed();
- // Return the icon to be shown for this InfoBar. If the returned Image is
- // NULL, no icon is shown.
- virtual gfx::Image* GetIcon() const;
+ // Return the resource ID of the icon to be shown for this InfoBar. If the
+ // value is equal to |kNoIconID|, no icon is shown.
+ virtual int GetIconID() const;
// Returns the type of the infobar. The type determines the appearance (such
// as background color) of the infobar.
@@ -99,6 +102,10 @@ class InfoBarDelegate {
virtual ThreeDAPIInfoBarDelegate* AsThreeDAPIInfoBarDelegate();
virtual TranslateInfoBarDelegate* AsTranslateInfoBarDelegate();
+ // Return the icon to be shown for this InfoBar. If the returned Image is
+ // empty, no icon is shown.
+ gfx::Image GetIcon() const;
+
content::WebContents* web_contents() {
return owner_ ? owner_->web_contents() : NULL;
}
« no previous file with comments | « chrome/browser/geolocation/geolocation_infobar_delegate.cc ('k') | chrome/browser/infobars/infobar_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698